# Interpretable Federated Rule Algorithm

This algorithm generates an interpretable explaining ruleset based on a target Y and features X through 
a federated learning, where each node generates a ruleset from a single decision tree.